This is a  package for sentiment analysis in any language . You can use for overall sentiment for a entire paragraph or a sentence in anylanguage.
Languages as per : https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
Example :
>>from anysentiment import anysentimentDF,overallsentiment